# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_channel_result import CreateChannelResult
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateOsvcChannelResult(CreateChannelResult):
    """
    The configuration for an OSVC channel.
    """

    #: A constant which can be used with the channel_service property of a CreateOsvcChannelResult.
    #: This constant has a value of "OSVC"
    CHANNEL_SERVICE_OSVC = "OSVC"

    #: A constant which can be used with the channel_service property of a CreateOsvcChannelResult.
    #: This constant has a value of "FUSION"
    CHANNEL_SERVICE_FUSION = "FUSION"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateOsvcChannelResult object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.CreateOsvcChannelResult.type` attribute
        of this class is ``OSVC`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CreateOsvcChannelResult.
        :type id: str

        :param name:
            The value to assign to the name property of this CreateOsvcChannelResult.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateOsvcChannelResult.
        :type description: str

        :param category:
            The value to assign to the category property of this CreateOsvcChannelResult.
            Allowed values for this property are: "AGENT", "APPLICATION", "BOT", "BOT_AS_AGENT", "SYSTEM", "EVENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        :param type:
            The value to assign to the type property of this CreateOsvcChannelResult.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this CreateOsvcChannelResult.
        :type session_expiry_duration_in_milliseconds: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CreateOsvcChannelResult.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this CreateOsvcChannelResult.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this CreateOsvcChannelResult.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateOsvcChannelResult.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateOsvcChannelResult.
        :type defined_tags: dict(str, dict(str, object))

        :param host:
            The value to assign to the host property of this CreateOsvcChannelResult.
        :type host: str

        :param port:
            The value to assign to the port property of this CreateOsvcChannelResult.
        :type port: str

        :param user_name:
            The value to assign to the user_name property of this CreateOsvcChannelResult.
        :type user_name: str

        :param total_session_count:
            The value to assign to the total_session_count property of this CreateOsvcChannelResult.
        :type total_session_count: int

        :param channel_service:
            The value to assign to the channel_service property of this CreateOsvcChannelResult.
            Allowed values for this property are: "OSVC", "FUSION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type channel_service: str

        :param authentication_provider_name:
            The value to assign to the authentication_provider_name property of this CreateOsvcChannelResult.
        :type authentication_provider_name: str

        :param bot_id:
            The value to assign to the bot_id property of this CreateOsvcChannelResult.
        :type bot_id: str

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'category': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'host': 'str',
            'port': 'str',
            'user_name': 'str',
            'total_session_count': 'int',
            'channel_service': 'str',
            'authentication_provider_name': 'str',
            'bot_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'category': 'category',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'host': 'host',
            'port': 'port',
            'user_name': 'userName',
            'total_session_count': 'totalSessionCount',
            'channel_service': 'channelService',
            'authentication_provider_name': 'authenticationProviderName',
            'bot_id': 'botId'
        }

        self._id = None
        self._name = None
        self._description = None
        self._category = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None
        self._host = None
        self._port = None
        self._user_name = None
        self._total_session_count = None
        self._channel_service = None
        self._authentication_provider_name = None
        self._bot_id = None
        self._type = 'OSVC'

    @property
    def host(self):
        """
        **[Required]** Gets the host of this CreateOsvcChannelResult.
        The host.

        For OSVC, you can derive these values from the URL that you use to launch the Agent Browser User Interface
        or the chat launch page. For example, if the URL is https://sitename.exampledomain.com/app/chat/chat_launch,
        then the host is sitename.exampledomain.com.

        For FUSION, this is the host portion of your Oracle Applications Cloud (Fusion) instance's URL.
        For example: sitename.exampledomain.com.


        :return: The host of this CreateOsvcChannelResult.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this CreateOsvcChannelResult.
        The host.

        For OSVC, you can derive these values from the URL that you use to launch the Agent Browser User Interface
        or the chat launch page. For example, if the URL is https://sitename.exampledomain.com/app/chat/chat_launch,
        then the host is sitename.exampledomain.com.

        For FUSION, this is the host portion of your Oracle Applications Cloud (Fusion) instance's URL.
        For example: sitename.exampledomain.com.


        :param host: The host of this CreateOsvcChannelResult.
        :type: str
        """
        self._host = host

    @property
    def port(self):
        """
        **[Required]** Gets the port of this CreateOsvcChannelResult.
        The port.


        :return: The port of this CreateOsvcChannelResult.
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this CreateOsvcChannelResult.
        The port.


        :param port: The port of this CreateOsvcChannelResult.
        :type: str
        """
        self._port = port

    @property
    def user_name(self):
        """
        **[Required]** Gets the user_name of this CreateOsvcChannelResult.
        The user name for the digital-assistant agent.


        :return: The user_name of this CreateOsvcChannelResult.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this CreateOsvcChannelResult.
        The user name for the digital-assistant agent.


        :param user_name: The user_name of this CreateOsvcChannelResult.
        :type: str
        """
        self._user_name = user_name

    @property
    def total_session_count(self):
        """
        **[Required]** Gets the total_session_count of this CreateOsvcChannelResult.
        The total session count.


        :return: The total_session_count of this CreateOsvcChannelResult.
        :rtype: int
        """
        return self._total_session_count

    @total_session_count.setter
    def total_session_count(self, total_session_count):
        """
        Sets the total_session_count of this CreateOsvcChannelResult.
        The total session count.


        :param total_session_count: The total_session_count of this CreateOsvcChannelResult.
        :type: int
        """
        self._total_session_count = total_session_count

    @property
    def channel_service(self):
        """
        **[Required]** Gets the channel_service of this CreateOsvcChannelResult.
        The type of OSVC service.

        Allowed values for this property are: "OSVC", "FUSION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The channel_service of this CreateOsvcChannelResult.
        :rtype: str
        """
        return self._channel_service

    @channel_service.setter
    def channel_service(self, channel_service):
        """
        Sets the channel_service of this CreateOsvcChannelResult.
        The type of OSVC service.


        :param channel_service: The channel_service of this CreateOsvcChannelResult.
        :type: str
        """
        allowed_values = ["OSVC", "FUSION"]
        if not value_allowed_none_or_none_sentinel(channel_service, allowed_values):
            channel_service = 'UNKNOWN_ENUM_VALUE'
        self._channel_service = channel_service

    @property
    def authentication_provider_name(self):
        """
        **[Required]** Gets the authentication_provider_name of this CreateOsvcChannelResult.
        The name of the Authentication Provider to use to authenticate the user.


        :return: The authentication_provider_name of this CreateOsvcChannelResult.
        :rtype: str
        """
        return self._authentication_provider_name

    @authentication_provider_name.setter
    def authentication_provider_name(self, authentication_provider_name):
        """
        Sets the authentication_provider_name of this CreateOsvcChannelResult.
        The name of the Authentication Provider to use to authenticate the user.


        :param authentication_provider_name: The authentication_provider_name of this CreateOsvcChannelResult.
        :type: str
        """
        self._authentication_provider_name = authentication_provider_name

    @property
    def bot_id(self):
        """
        Gets the bot_id of this CreateOsvcChannelResult.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :return: The bot_id of this CreateOsvcChannelResult.
        :rtype: str
        """
        return self._bot_id

    @bot_id.setter
    def bot_id(self, bot_id):
        """
        Sets the bot_id of this CreateOsvcChannelResult.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :param bot_id: The bot_id of this CreateOsvcChannelResult.
        :type: str
        """
        self._bot_id = bot_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateMonitoredResourceDetails(object):
    """
    The information about updating a monitored resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateMonitoredResourceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateMonitoredResourceDetails.
        :type display_name: str

        :param host_name:
            The value to assign to the host_name property of this UpdateMonitoredResourceDetails.
        :type host_name: str

        :param resource_time_zone:
            The value to assign to the resource_time_zone property of this UpdateMonitoredResourceDetails.
        :type resource_time_zone: str

        :param properties:
            The value to assign to the properties property of this UpdateMonitoredResourceDetails.
        :type properties: list[oci.stack_monitoring.models.MonitoredResourceProperty]

        :param database_connection_details:
            The value to assign to the database_connection_details property of this UpdateMonitoredResourceDetails.
        :type database_connection_details: oci.stack_monitoring.models.ConnectionDetails

        :param credentials:
            The value to assign to the credentials property of this UpdateMonitoredResourceDetails.
        :type credentials: oci.stack_monitoring.models.MonitoredResourceCredential

        :param aliases:
            The value to assign to the aliases property of this UpdateMonitoredResourceDetails.
        :type aliases: oci.stack_monitoring.models.MonitoredResourceAliasCredential

        """
        self.swagger_types = {
            'display_name': 'str',
            'host_name': 'str',
            'resource_time_zone': 'str',
            'properties': 'list[MonitoredResourceProperty]',
            'database_connection_details': 'ConnectionDetails',
            'credentials': 'MonitoredResourceCredential',
            'aliases': 'MonitoredResourceAliasCredential'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'host_name': 'hostName',
            'resource_time_zone': 'resourceTimeZone',
            'properties': 'properties',
            'database_connection_details': 'databaseConnectionDetails',
            'credentials': 'credentials',
            'aliases': 'aliases'
        }

        self._display_name = None
        self._host_name = None
        self._resource_time_zone = None
        self._properties = None
        self._database_connection_details = None
        self._credentials = None
        self._aliases = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateMonitoredResourceDetails.
        Monitored resource display name.


        :return: The display_name of this UpdateMonitoredResourceDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateMonitoredResourceDetails.
        Monitored resource display name.


        :param display_name: The display_name of this UpdateMonitoredResourceDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def host_name(self):
        """
        Gets the host_name of this UpdateMonitoredResourceDetails.
        Host name of the monitored resource


        :return: The host_name of this UpdateMonitoredResourceDetails.
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """
        Sets the host_name of this UpdateMonitoredResourceDetails.
        Host name of the monitored resource


        :param host_name: The host_name of this UpdateMonitoredResourceDetails.
        :type: str
        """
        self._host_name = host_name

    @property
    def resource_time_zone(self):
        """
        Gets the resource_time_zone of this UpdateMonitoredResourceDetails.
        Time zone in the form of tz database canonical zone ID.


        :return: The resource_time_zone of this UpdateMonitoredResourceDetails.
        :rtype: str
        """
        return self._resource_time_zone

    @resource_time_zone.setter
    def resource_time_zone(self, resource_time_zone):
        """
        Sets the resource_time_zone of this UpdateMonitoredResourceDetails.
        Time zone in the form of tz database canonical zone ID.


        :param resource_time_zone: The resource_time_zone of this UpdateMonitoredResourceDetails.
        :type: str
        """
        self._resource_time_zone = resource_time_zone

    @property
    def properties(self):
        """
        Gets the properties of this UpdateMonitoredResourceDetails.
        List of monitored resource properties


        :return: The properties of this UpdateMonitoredResourceDetails.
        :rtype: list[oci.stack_monitoring.models.MonitoredResourceProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this UpdateMonitoredResourceDetails.
        List of monitored resource properties


        :param properties: The properties of this UpdateMonitoredResourceDetails.
        :type: list[oci.stack_monitoring.models.MonitoredResourceProperty]
        """
        self._properties = properties

    @property
    def database_connection_details(self):
        """
        Gets the database_connection_details of this UpdateMonitoredResourceDetails.

        :return: The database_connection_details of this UpdateMonitoredResourceDetails.
        :rtype: oci.stack_monitoring.models.ConnectionDetails
        """
        return self._database_connection_details

    @database_connection_details.setter
    def database_connection_details(self, database_connection_details):
        """
        Sets the database_connection_details of this UpdateMonitoredResourceDetails.

        :param database_connection_details: The database_connection_details of this UpdateMonitoredResourceDetails.
        :type: oci.stack_monitoring.models.ConnectionDetails
        """
        self._database_connection_details = database_connection_details

    @property
    def credentials(self):
        """
        Gets the credentials of this UpdateMonitoredResourceDetails.

        :return: The credentials of this UpdateMonitoredResourceDetails.
        :rtype: oci.stack_monitoring.models.MonitoredResourceCredential
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """
        Sets the credentials of this UpdateMonitoredResourceDetails.

        :param credentials: The credentials of this UpdateMonitoredResourceDetails.
        :type: oci.stack_monitoring.models.MonitoredResourceCredential
        """
        self._credentials = credentials

    @property
    def aliases(self):
        """
        Gets the aliases of this UpdateMonitoredResourceDetails.

        :return: The aliases of this UpdateMonitoredResourceDetails.
        :rtype: oci.stack_monitoring.models.MonitoredResourceAliasCredential
        """
        return self._aliases

    @aliases.setter
    def aliases(self, aliases):
        """
        Sets the aliases of this UpdateMonitoredResourceDetails.

        :param aliases: The aliases of this UpdateMonitoredResourceDetails.
        :type: oci.stack_monitoring.models.MonitoredResourceAliasCredential
        """
        self._aliases = aliases

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCertificateConfigDetails(object):
    """
    The details of the contents of the certificate and certificate metadata.
    """

    #: A constant which can be used with the config_type property of a CreateCertificateConfigDetails.
    #: This constant has a value of "ISSUED_BY_INTERNAL_CA"
    CONFIG_TYPE_ISSUED_BY_INTERNAL_CA = "ISSUED_BY_INTERNAL_CA"

    #: A constant which can be used with the config_type property of a CreateCertificateConfigDetails.
    #: This constant has a value of "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA"
    CONFIG_TYPE_MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA = "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA"

    #: A constant which can be used with the config_type property of a CreateCertificateConfigDetails.
    #: This constant has a value of "IMPORTED"
    CONFIG_TYPE_IMPORTED = "IMPORTED"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCertificateConfigDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.certificates_management.models.CreateCertificateManagedExternallyIssuedByInternalCaConfigDetails`
        * :class:`~oci.certificates_management.models.CreateCertificateIssuedByInternalCaConfigDetails`
        * :class:`~oci.certificates_management.models.CreateCertificateByImportingConfigDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_type:
            The value to assign to the config_type property of this CreateCertificateConfigDetails.
            Allowed values for this property are: "ISSUED_BY_INTERNAL_CA", "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA", "IMPORTED"
        :type config_type: str

        :param version_name:
            The value to assign to the version_name property of this CreateCertificateConfigDetails.
        :type version_name: str

        """
        self.swagger_types = {
            'config_type': 'str',
            'version_name': 'str'
        }

        self.attribute_map = {
            'config_type': 'configType',
            'version_name': 'versionName'
        }

        self._config_type = None
        self._version_name = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['configType']

        if type == 'MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA':
            return 'CreateCertificateManagedExternallyIssuedByInternalCaConfigDetails'

        if type == 'ISSUED_BY_INTERNAL_CA':
            return 'CreateCertificateIssuedByInternalCaConfigDetails'

        if type == 'IMPORTED':
            return 'CreateCertificateByImportingConfigDetails'
        else:
            return 'CreateCertificateConfigDetails'

    @property
    def config_type(self):
        """
        **[Required]** Gets the config_type of this CreateCertificateConfigDetails.
        The origin of the certificate.

        Allowed values for this property are: "ISSUED_BY_INTERNAL_CA", "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA", "IMPORTED"


        :return: The config_type of this CreateCertificateConfigDetails.
        :rtype: str
        """
        return self._config_type

    @config_type.setter
    def config_type(self, config_type):
        """
        Sets the config_type of this CreateCertificateConfigDetails.
        The origin of the certificate.


        :param config_type: The config_type of this CreateCertificateConfigDetails.
        :type: str
        """
        allowed_values = ["ISSUED_BY_INTERNAL_CA", "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA", "IMPORTED"]
        if not value_allowed_none_or_none_sentinel(config_type, allowed_values):
            raise ValueError(
                "Invalid value for `config_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._config_type = config_type

    @property
    def version_name(self):
        """
        Gets the version_name of this CreateCertificateConfigDetails.
        A name for the certificate. When the value is not null, a name is unique across versions of a given certificate.


        :return: The version_name of this CreateCertificateConfigDetails.
        :rtype: str
        """
        return self._version_name

    @version_name.setter
    def version_name(self, version_name):
        """
        Sets the version_name of this CreateCertificateConfigDetails.
        A name for the certificate. When the value is not null, a name is unique across versions of a given certificate.


        :param version_name: The version_name of this CreateCertificateConfigDetails.
        :type: str
        """
        self._version_name = version_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateNetworkFirewallPolicyDetails(object):
    """
    The request details to be updated in the firewall policy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateNetworkFirewallPolicyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateNetworkFirewallPolicyDetails.
        :type display_name: str

        :param mapped_secrets:
            The value to assign to the mapped_secrets property of this UpdateNetworkFirewallPolicyDetails.
        :type mapped_secrets: dict(str, MappedSecret)

        :param application_lists:
            The value to assign to the application_lists property of this UpdateNetworkFirewallPolicyDetails.
        :type application_lists: dict(str, list[Application])

        :param url_lists:
            The value to assign to the url_lists property of this UpdateNetworkFirewallPolicyDetails.
        :type url_lists: dict(str, list[UrlPattern])

        :param ip_address_lists:
            The value to assign to the ip_address_lists property of this UpdateNetworkFirewallPolicyDetails.
        :type ip_address_lists: dict(str, list[str])

        :param security_rules:
            The value to assign to the security_rules property of this UpdateNetworkFirewallPolicyDetails.
        :type security_rules: list[oci.network_firewall.models.SecurityRule]

        :param decryption_rules:
            The value to assign to the decryption_rules property of this UpdateNetworkFirewallPolicyDetails.
        :type decryption_rules: list[oci.network_firewall.models.DecryptionRule]

        :param decryption_profiles:
            The value to assign to the decryption_profiles property of this UpdateNetworkFirewallPolicyDetails.
        :type decryption_profiles: dict(str, DecryptionProfile)

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateNetworkFirewallPolicyDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateNetworkFirewallPolicyDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'mapped_secrets': 'dict(str, MappedSecret)',
            'application_lists': 'dict(str, list[Application])',
            'url_lists': 'dict(str, list[UrlPattern])',
            'ip_address_lists': 'dict(str, list[str])',
            'security_rules': 'list[SecurityRule]',
            'decryption_rules': 'list[DecryptionRule]',
            'decryption_profiles': 'dict(str, DecryptionProfile)',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'mapped_secrets': 'mappedSecrets',
            'application_lists': 'applicationLists',
            'url_lists': 'urlLists',
            'ip_address_lists': 'ipAddressLists',
            'security_rules': 'securityRules',
            'decryption_rules': 'decryptionRules',
            'decryption_profiles': 'decryptionProfiles',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._mapped_secrets = None
        self._application_lists = None
        self._url_lists = None
        self._ip_address_lists = None
        self._security_rules = None
        self._decryption_rules = None
        self._decryption_profiles = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateNetworkFirewallPolicyDetails.
        A user-friendly name for the firewall. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this UpdateNetworkFirewallPolicyDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateNetworkFirewallPolicyDetails.
        A user-friendly name for the firewall. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this UpdateNetworkFirewallPolicyDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def mapped_secrets(self):
        """
        Gets the mapped_secrets of this UpdateNetworkFirewallPolicyDetails.
        Map defining secrets of the policy.
        The value of an entry is a \"mapped secret\" consisting of a purpose and source.
        The associated key is the identifier by which the mapped secret is referenced.


        :return: The mapped_secrets of this UpdateNetworkFirewallPolicyDetails.
        :rtype: dict(str, MappedSecret)
        """
        return self._mapped_secrets

    @mapped_secrets.setter
    def mapped_secrets(self, mapped_secrets):
        """
        Sets the mapped_secrets of this UpdateNetworkFirewallPolicyDetails.
        Map defining secrets of the policy.
        The value of an entry is a \"mapped secret\" consisting of a purpose and source.
        The associated key is the identifier by which the mapped secret is referenced.


        :param mapped_secrets: The mapped_secrets of this UpdateNetworkFirewallPolicyDetails.
        :type: dict(str, MappedSecret)
        """
        self._mapped_secrets = mapped_secrets

    @property
    def application_lists(self):
        """
        Gets the application_lists of this UpdateNetworkFirewallPolicyDetails.
        Map defining application lists of the policy.
        The value of an entry is a list of \"applications\", each consisting of a protocol identifier (such as TCP, UDP, or ICMP) and protocol-specific parameters (such as a port range).
        The associated key is the identifier by which the application list is referenced.


        :return: The application_lists of this UpdateNetworkFirewallPolicyDetails.
        :rtype: dict(str, list[Application])
        """
        return self._application_lists

    @application_lists.setter
    def application_lists(self, application_lists):
        """
        Sets the application_lists of this UpdateNetworkFirewallPolicyDetails.
        Map defining application lists of the policy.
        The value of an entry is a list of \"applications\", each consisting of a protocol identifier (such as TCP, UDP, or ICMP) and protocol-specific parameters (such as a port range).
        The associated key is the identifier by which the application list is referenced.


        :param application_lists: The application_lists of this UpdateNetworkFirewallPolicyDetails.
        :type: dict(str, list[Application])
        """
        self._application_lists = application_lists

    @property
    def url_lists(self):
        """
        Gets the url_lists of this UpdateNetworkFirewallPolicyDetails.
        Map defining URL pattern lists of the policy.
        The value of an entry is a list of URL patterns.
        The associated key is the identifier by which the URL pattern list is referenced.


        :return: The url_lists of this UpdateNetworkFirewallPolicyDetails.
        :rtype: dict(str, list[UrlPattern])
        """
        return self._url_lists

    @url_lists.setter
    def url_lists(self, url_lists):
        """
        Sets the url_lists of this UpdateNetworkFirewallPolicyDetails.
        Map defining URL pattern lists of the policy.
        The value of an entry is a list of URL patterns.
        The associated key is the identifier by which the URL pattern list is referenced.


        :param url_lists: The url_lists of this UpdateNetworkFirewallPolicyDetails.
        :type: dict(str, list[UrlPattern])
        """
        self._url_lists = url_lists

    @property
    def ip_address_lists(self):
        """
        Gets the ip_address_lists of this UpdateNetworkFirewallPolicyDetails.
        Map defining IP address lists of the policy.
        The value of an entry is a list of IP addresses or prefixes in CIDR notation.
        The associated key is the identifier by which the IP address list is referenced.


        :return: The ip_address_lists of this UpdateNetworkFirewallPolicyDetails.
        :rtype: dict(str, list[str])
        """
        return self._ip_address_lists

    @ip_address_lists.setter
    def ip_address_lists(self, ip_address_lists):
        """
        Sets the ip_address_lists of this UpdateNetworkFirewallPolicyDetails.
        Map defining IP address lists of the policy.
        The value of an entry is a list of IP addresses or prefixes in CIDR notation.
        The associated key is the identifier by which the IP address list is referenced.


        :param ip_address_lists: The ip_address_lists of this UpdateNetworkFirewallPolicyDetails.
        :type: dict(str, list[str])
        """
        self._ip_address_lists = ip_address_lists

    @property
    def security_rules(self):
        """
        Gets the security_rules of this UpdateNetworkFirewallPolicyDetails.
        List of Security Rules defining the behavior of the policy.
        The first rule with a matching condition determines the action taken upon network traffic.


        :return: The security_rules of this UpdateNetworkFirewallPolicyDetails.
        :rtype: list[oci.network_firewall.models.SecurityRule]
        """
        return self._security_rules

    @security_rules.setter
    def security_rules(self, security_rules):
        """
        Sets the security_rules of this UpdateNetworkFirewallPolicyDetails.
        List of Security Rules defining the behavior of the policy.
        The first rule with a matching condition determines the action taken upon network traffic.


        :param security_rules: The security_rules of this UpdateNetworkFirewallPolicyDetails.
        :type: list[oci.network_firewall.models.SecurityRule]
        """
        self._security_rules = security_rules

    @property
    def decryption_rules(self):
        """
        Gets the decryption_rules of this UpdateNetworkFirewallPolicyDetails.
        List of Decryption Rules defining the behavior of the policy.
        The first rule with a matching condition determines the action taken upon network traffic.


        :return: The decryption_rules of this UpdateNetworkFirewallPolicyDetails.
        :rtype: list[oci.network_firewall.models.DecryptionRule]
        """
        return self._decryption_rules

    @decryption_rules.setter
    def decryption_rules(self, decryption_rules):
        """
        Sets the decryption_rules of this UpdateNetworkFirewallPolicyDetails.
        List of Decryption Rules defining the behavior of the policy.
        The first rule with a matching condition determines the action taken upon network traffic.


        :param decryption_rules: The decryption_rules of this UpdateNetworkFirewallPolicyDetails.
        :type: list[oci.network_firewall.models.DecryptionRule]
        """
        self._decryption_rules = decryption_rules

    @property
    def decryption_profiles(self):
        """
        Gets the decryption_profiles of this UpdateNetworkFirewallPolicyDetails.
        Map defining decryption profiles of the policy.
        The value of an entry is a decryption profile.
        The associated key is the identifier by which the decryption profile is referenced.


        :return: The decryption_profiles of this UpdateNetworkFirewallPolicyDetails.
        :rtype: dict(str, DecryptionProfile)
        """
        return self._decryption_profiles

    @decryption_profiles.setter
    def decryption_profiles(self, decryption_profiles):
        """
        Sets the decryption_profiles of this UpdateNetworkFirewallPolicyDetails.
        Map defining decryption profiles of the policy.
        The value of an entry is a decryption profile.
        The associated key is the identifier by which the decryption profile is referenced.


        :param decryption_profiles: The decryption_profiles of this UpdateNetworkFirewallPolicyDetails.
        :type: dict(str, DecryptionProfile)
        """
        self._decryption_profiles = decryption_profiles

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateNetworkFirewallPolicyDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateNetworkFirewallPolicyDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateNetworkFirewallPolicyDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateNetworkFirewallPolicyDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateNetworkFirewallPolicyDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateNetworkFirewallPolicyDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateNetworkFirewallPolicyDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateNetworkFirewallPolicyDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_exadata_insight_details import CreateExadataInsightDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateEmManagedExternalExadataInsightDetails(CreateExadataInsightDetails):
    """
    The information about the Exadata system to be analyzed. If memberEntityDetails is not specified, the the Enterprise Manager entity (e.g. databases and hosts) associated with an Exadata system will be placed in the same compartment as the Exadata system.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateEmManagedExternalExadataInsightDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.CreateEmManagedExternalExadataInsightDetails.entity_source` attribute
        of this class is ``EM_MANAGED_EXTERNAL_EXADATA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this CreateEmManagedExternalExadataInsightDetails.
            Allowed values for this property are: "EM_MANAGED_EXTERNAL_EXADATA"
        :type entity_source: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateEmManagedExternalExadataInsightDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateEmManagedExternalExadataInsightDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateEmManagedExternalExadataInsightDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param enterprise_manager_identifier:
            The value to assign to the enterprise_manager_identifier property of this CreateEmManagedExternalExadataInsightDetails.
        :type enterprise_manager_identifier: str

        :param enterprise_manager_bridge_id:
            The value to assign to the enterprise_manager_bridge_id property of this CreateEmManagedExternalExadataInsightDetails.
        :type enterprise_manager_bridge_id: str

        :param enterprise_manager_entity_identifier:
            The value to assign to the enterprise_manager_entity_identifier property of this CreateEmManagedExternalExadataInsightDetails.
        :type enterprise_manager_entity_identifier: str

        :param member_entity_details:
            The value to assign to the member_entity_details property of this CreateEmManagedExternalExadataInsightDetails.
        :type member_entity_details: list[oci.opsi.models.CreateEmManagedExternalExadataMemberEntityDetails]

        :param is_auto_sync_enabled:
            The value to assign to the is_auto_sync_enabled property of this CreateEmManagedExternalExadataInsightDetails.
        :type is_auto_sync_enabled: bool

        """
        self.swagger_types = {
            'entity_source': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'enterprise_manager_identifier': 'str',
            'enterprise_manager_bridge_id': 'str',
            'enterprise_manager_entity_identifier': 'str',
            'member_entity_details': 'list[CreateEmManagedExternalExadataMemberEntityDetails]',
            'is_auto_sync_enabled': 'bool'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'enterprise_manager_identifier': 'enterpriseManagerIdentifier',
            'enterprise_manager_bridge_id': 'enterpriseManagerBridgeId',
            'enterprise_manager_entity_identifier': 'enterpriseManagerEntityIdentifier',
            'member_entity_details': 'memberEntityDetails',
            'is_auto_sync_enabled': 'isAutoSyncEnabled'
        }

        self._entity_source = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._enterprise_manager_identifier = None
        self._enterprise_manager_bridge_id = None
        self._enterprise_manager_entity_identifier = None
        self._member_entity_details = None
        self._is_auto_sync_enabled = None
        self._entity_source = 'EM_MANAGED_EXTERNAL_EXADATA'

    @property
    def enterprise_manager_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_identifier of this CreateEmManagedExternalExadataInsightDetails.
        Enterprise Manager Unique Identifier


        :return: The enterprise_manager_identifier of this CreateEmManagedExternalExadataInsightDetails.
        :rtype: str
        """
        return self._enterprise_manager_identifier

    @enterprise_manager_identifier.setter
    def enterprise_manager_identifier(self, enterprise_manager_identifier):
        """
        Sets the enterprise_manager_identifier of this CreateEmManagedExternalExadataInsightDetails.
        Enterprise Manager Unique Identifier


        :param enterprise_manager_identifier: The enterprise_manager_identifier of this CreateEmManagedExternalExadataInsightDetails.
        :type: str
        """
        self._enterprise_manager_identifier = enterprise_manager_identifier

    @property
    def enterprise_manager_bridge_id(self):
        """
        **[Required]** Gets the enterprise_manager_bridge_id of this CreateEmManagedExternalExadataInsightDetails.
        OPSI Enterprise Manager Bridge OCID


        :return: The enterprise_manager_bridge_id of this CreateEmManagedExternalExadataInsightDetails.
        :rtype: str
        """
        return self._enterprise_manager_bridge_id

    @enterprise_manager_bridge_id.setter
    def enterprise_manager_bridge_id(self, enterprise_manager_bridge_id):
        """
        Sets the enterprise_manager_bridge_id of this CreateEmManagedExternalExadataInsightDetails.
        OPSI Enterprise Manager Bridge OCID


        :param enterprise_manager_bridge_id: The enterprise_manager_bridge_id of this CreateEmManagedExternalExadataInsightDetails.
        :type: str
        """
        self._enterprise_manager_bridge_id = enterprise_manager_bridge_id

    @property
    def enterprise_manager_entity_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_entity_identifier of this CreateEmManagedExternalExadataInsightDetails.
        Enterprise Manager Entity Unique Identifier


        :return: The enterprise_manager_entity_identifier of this CreateEmManagedExternalExadataInsightDetails.
        :rtype: str
        """
        return self._enterprise_manager_entity_identifier

    @enterprise_manager_entity_identifier.setter
    def enterprise_manager_entity_identifier(self, enterprise_manager_entity_identifier):
        """
        Sets the enterprise_manager_entity_identifier of this CreateEmManagedExternalExadataInsightDetails.
        Enterprise Manager Entity Unique Identifier


        :param enterprise_manager_entity_identifier: The enterprise_manager_entity_identifier of this CreateEmManagedExternalExadataInsightDetails.
        :type: str
        """
        self._enterprise_manager_entity_identifier = enterprise_manager_entity_identifier

    @property
    def member_entity_details(self):
        """
        Gets the member_entity_details of this CreateEmManagedExternalExadataInsightDetails.

        :return: The member_entity_details of this CreateEmManagedExternalExadataInsightDetails.
        :rtype: list[oci.opsi.models.CreateEmManagedExternalExadataMemberEntityDetails]
        """
        return self._member_entity_details

    @member_entity_details.setter
    def member_entity_details(self, member_entity_details):
        """
        Sets the member_entity_details of this CreateEmManagedExternalExadataInsightDetails.

        :param member_entity_details: The member_entity_details of this CreateEmManagedExternalExadataInsightDetails.
        :type: list[oci.opsi.models.CreateEmManagedExternalExadataMemberEntityDetails]
        """
        self._member_entity_details = member_entity_details

    @property
    def is_auto_sync_enabled(self):
        """
        Gets the is_auto_sync_enabled of this CreateEmManagedExternalExadataInsightDetails.
        Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager. New resources (e.g. Database Insights) will be placed in the same compartment as the related Exadata Insight.


        :return: The is_auto_sync_enabled of this CreateEmManagedExternalExadataInsightDetails.
        :rtype: bool
        """
        return self._is_auto_sync_enabled

    @is_auto_sync_enabled.setter
    def is_auto_sync_enabled(self, is_auto_sync_enabled):
        """
        Sets the is_auto_sync_enabled of this CreateEmManagedExternalExadataInsightDetails.
        Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager. New resources (e.g. Database Insights) will be placed in the same compartment as the related Exadata Insight.


        :param is_auto_sync_enabled: The is_auto_sync_enabled of this CreateEmManagedExternalExadataInsightDetails.
        :type: bool
        """
        self._is_auto_sync_enabled = is_auto_sync_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_certificate_config_details import CreateCertificateConfigDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCertificateIssuedByInternalCaConfigDetails(CreateCertificateConfigDetails):
    """
    The details of the configuration for creating an internally managed certificate which is issued by a private certificate authority (CA).
    """

    #: A constant which can be used with the certificate_profile_type property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "TLS_SERVER_OR_CLIENT"
    CERTIFICATE_PROFILE_TYPE_TLS_SERVER_OR_CLIENT = "TLS_SERVER_OR_CLIENT"

    #: A constant which can be used with the certificate_profile_type property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "TLS_SERVER"
    CERTIFICATE_PROFILE_TYPE_TLS_SERVER = "TLS_SERVER"

    #: A constant which can be used with the certificate_profile_type property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "TLS_CLIENT"
    CERTIFICATE_PROFILE_TYPE_TLS_CLIENT = "TLS_CLIENT"

    #: A constant which can be used with the certificate_profile_type property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "TLS_CODE_SIGN"
    CERTIFICATE_PROFILE_TYPE_TLS_CODE_SIGN = "TLS_CODE_SIGN"

    #: A constant which can be used with the key_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "RSA2048"
    KEY_ALGORITHM_RSA2048 = "RSA2048"

    #: A constant which can be used with the key_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "RSA4096"
    KEY_ALGORITHM_RSA4096 = "RSA4096"

    #: A constant which can be used with the key_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "ECDSA_P256"
    KEY_ALGORITHM_ECDSA_P256 = "ECDSA_P256"

    #: A constant which can be used with the key_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "ECDSA_P384"
    KEY_ALGORITHM_ECDSA_P384 = "ECDSA_P384"

    #: A constant which can be used with the signature_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "SHA256_WITH_RSA"
    SIGNATURE_ALGORITHM_SHA256_WITH_RSA = "SHA256_WITH_RSA"

    #: A constant which can be used with the signature_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "SHA384_WITH_RSA"
    SIGNATURE_ALGORITHM_SHA384_WITH_RSA = "SHA384_WITH_RSA"

    #: A constant which can be used with the signature_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "SHA512_WITH_RSA"
    SIGNATURE_ALGORITHM_SHA512_WITH_RSA = "SHA512_WITH_RSA"

    #: A constant which can be used with the signature_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "SHA256_WITH_ECDSA"
    SIGNATURE_ALGORITHM_SHA256_WITH_ECDSA = "SHA256_WITH_ECDSA"

    #: A constant which can be used with the signature_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "SHA384_WITH_ECDSA"
    SIGNATURE_ALGORITHM_SHA384_WITH_ECDSA = "SHA384_WITH_ECDSA"

    #: A constant which can be used with the signature_algorithm property of a CreateCertificateIssuedByInternalCaConfigDetails.
    #: This constant has a value of "SHA512_WITH_ECDSA"
    SIGNATURE_ALGORITHM_SHA512_WITH_ECDSA = "SHA512_WITH_ECDSA"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCertificateIssuedByInternalCaConfigDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.certificates_management.models.CreateCertificateIssuedByInternalCaConfigDetails.config_type` attribute
        of this class is ``ISSUED_BY_INTERNAL_CA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_type:
            The value to assign to the config_type property of this CreateCertificateIssuedByInternalCaConfigDetails.
            Allowed values for this property are: "ISSUED_BY_INTERNAL_CA", "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA", "IMPORTED"
        :type config_type: str

        :param version_name:
            The value to assign to the version_name property of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type version_name: str

        :param certificate_profile_type:
            The value to assign to the certificate_profile_type property of this CreateCertificateIssuedByInternalCaConfigDetails.
            Allowed values for this property are: "TLS_SERVER_OR_CLIENT", "TLS_SERVER", "TLS_CLIENT", "TLS_CODE_SIGN"
        :type certificate_profile_type: str

        :param issuer_certificate_authority_id:
            The value to assign to the issuer_certificate_authority_id property of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type issuer_certificate_authority_id: str

        :param validity:
            The value to assign to the validity property of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type validity: oci.certificates_management.models.Validity

        :param subject:
            The value to assign to the subject property of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type subject: oci.certificates_management.models.CertificateSubject

        :param subject_alternative_names:
            The value to assign to the subject_alternative_names property of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type subject_alternative_names: list[oci.certificates_management.models.CertificateSubjectAlternativeName]

        :param key_algorithm:
            The value to assign to the key_algorithm property of this CreateCertificateIssuedByInternalCaConfigDetails.
            Allowed values for this property are: "RSA2048", "RSA4096", "ECDSA_P256", "ECDSA_P384"
        :type key_algorithm: str

        :param signature_algorithm:
            The value to assign to the signature_algorithm property of this CreateCertificateIssuedByInternalCaConfigDetails.
            Allowed values for this property are: "SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA"
        :type signature_algorithm: str

        """
        self.swagger_types = {
            'config_type': 'str',
            'version_name': 'str',
            'certificate_profile_type': 'str',
            'issuer_certificate_authority_id': 'str',
            'validity': 'Validity',
            'subject': 'CertificateSubject',
            'subject_alternative_names': 'list[CertificateSubjectAlternativeName]',
            'key_algorithm': 'str',
            'signature_algorithm': 'str'
        }

        self.attribute_map = {
            'config_type': 'configType',
            'version_name': 'versionName',
            'certificate_profile_type': 'certificateProfileType',
            'issuer_certificate_authority_id': 'issuerCertificateAuthorityId',
            'validity': 'validity',
            'subject': 'subject',
            'subject_alternative_names': 'subjectAlternativeNames',
            'key_algorithm': 'keyAlgorithm',
            'signature_algorithm': 'signatureAlgorithm'
        }

        self._config_type = None
        self._version_name = None
        self._certificate_profile_type = None
        self._issuer_certificate_authority_id = None
        self._validity = None
        self._subject = None
        self._subject_alternative_names = None
        self._key_algorithm = None
        self._signature_algorithm = None
        self._config_type = 'ISSUED_BY_INTERNAL_CA'

    @property
    def certificate_profile_type(self):
        """
        **[Required]** Gets the certificate_profile_type of this CreateCertificateIssuedByInternalCaConfigDetails.
        The name of the profile used to create the certificate, which depends on the type of certificate you need.

        Allowed values for this property are: "TLS_SERVER_OR_CLIENT", "TLS_SERVER", "TLS_CLIENT", "TLS_CODE_SIGN"


        :return: The certificate_profile_type of this CreateCertificateIssuedByInternalCaConfigDetails.
        :rtype: str
        """
        return self._certificate_profile_type

    @certificate_profile_type.setter
    def certificate_profile_type(self, certificate_profile_type):
        """
        Sets the certificate_profile_type of this CreateCertificateIssuedByInternalCaConfigDetails.
        The name of the profile used to create the certificate, which depends on the type of certificate you need.


        :param certificate_profile_type: The certificate_profile_type of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type: str
        """
        allowed_values = ["TLS_SERVER_OR_CLIENT", "TLS_SERVER", "TLS_CLIENT", "TLS_CODE_SIGN"]
        if not value_allowed_none_or_none_sentinel(certificate_profile_type, allowed_values):
            raise ValueError(
                "Invalid value for `certificate_profile_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._certificate_profile_type = certificate_profile_type

    @property
    def issuer_certificate_authority_id(self):
        """
        **[Required]** Gets the issuer_certificate_authority_id of this CreateCertificateIssuedByInternalCaConfigDetails.
        The OCID of the private CA.


        :return: The issuer_certificate_authority_id of this CreateCertificateIssuedByInternalCaConfigDetails.
        :rtype: str
        """
        return self._issuer_certificate_authority_id

    @issuer_certificate_authority_id.setter
    def issuer_certificate_authority_id(self, issuer_certificate_authority_id):
        """
        Sets the issuer_certificate_authority_id of this CreateCertificateIssuedByInternalCaConfigDetails.
        The OCID of the private CA.


        :param issuer_certificate_authority_id: The issuer_certificate_authority_id of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type: str
        """
        self._issuer_certificate_authority_id = issuer_certificate_authority_id

    @property
    def validity(self):
        """
        Gets the validity of this CreateCertificateIssuedByInternalCaConfigDetails.

        :return: The validity of this CreateCertificateIssuedByInternalCaConfigDetails.
        :rtype: oci.certificates_management.models.Validity
        """
        return self._validity

    @validity.setter
    def validity(self, validity):
        """
        Sets the validity of this CreateCertificateIssuedByInternalCaConfigDetails.

        :param validity: The validity of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type: oci.certificates_management.models.Validity
        """
        self._validity = validity

    @property
    def subject(self):
        """
        **[Required]** Gets the subject of this CreateCertificateIssuedByInternalCaConfigDetails.

        :return: The subject of this CreateCertificateIssuedByInternalCaConfigDetails.
        :rtype: oci.certificates_management.models.CertificateSubject
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this CreateCertificateIssuedByInternalCaConfigDetails.

        :param subject: The subject of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type: oci.certificates_management.models.CertificateSubject
        """
        self._subject = subject

    @property
    def subject_alternative_names(self):
        """
        Gets the subject_alternative_names of this CreateCertificateIssuedByInternalCaConfigDetails.
        A list of subject alternative names.


        :return: The subject_alternative_names of this CreateCertificateIssuedByInternalCaConfigDetails.
        :rtype: list[oci.certificates_management.models.CertificateSubjectAlternativeName]
        """
        return self._subject_alternative_names

    @subject_alternative_names.setter
    def subject_alternative_names(self, subject_alternative_names):
        """
        Sets the subject_alternative_names of this CreateCertificateIssuedByInternalCaConfigDetails.
        A list of subject alternative names.


        :param subject_alternative_names: The subject_alternative_names of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type: list[oci.certificates_management.models.CertificateSubjectAlternativeName]
        """
        self._subject_alternative_names = subject_alternative_names

    @property
    def key_algorithm(self):
        """
        Gets the key_algorithm of this CreateCertificateIssuedByInternalCaConfigDetails.
        The algorithm to use to create key pairs.

        Allowed values for this property are: "RSA2048", "RSA4096", "ECDSA_P256", "ECDSA_P384"


        :return: The key_algorithm of this CreateCertificateIssuedByInternalCaConfigDetails.
        :rtype: str
        """
        return self._key_algorithm

    @key_algorithm.setter
    def key_algorithm(self, key_algorithm):
        """
        Sets the key_algorithm of this CreateCertificateIssuedByInternalCaConfigDetails.
        The algorithm to use to create key pairs.


        :param key_algorithm: The key_algorithm of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type: str
        """
        allowed_values = ["RSA2048", "RSA4096", "ECDSA_P256", "ECDSA_P384"]
        if not value_allowed_none_or_none_sentinel(key_algorithm, allowed_values):
            raise ValueError(
                "Invalid value for `key_algorithm`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._key_algorithm = key_algorithm

    @property
    def signature_algorithm(self):
        """
        Gets the signature_algorithm of this CreateCertificateIssuedByInternalCaConfigDetails.
        The algorithm to use to sign the public key certificate.

        Allowed values for this property are: "SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA"


        :return: The signature_algorithm of this CreateCertificateIssuedByInternalCaConfigDetails.
        :rtype: str
        """
        return self._signature_algorithm

    @signature_algorithm.setter
    def signature_algorithm(self, signature_algorithm):
        """
        Sets the signature_algorithm of this CreateCertificateIssuedByInternalCaConfigDetails.
        The algorithm to use to sign the public key certificate.


        :param signature_algorithm: The signature_algorithm of this CreateCertificateIssuedByInternalCaConfigDetails.
        :type: str
        """
        allowed_values = ["SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA"]
        if not value_allowed_none_or_none_sentinel(signature_algorithm, allowed_values):
            raise ValueError(
                "Invalid value for `signature_algorithm`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._signature_algorithm = signature_algorithm

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCertificateAuthorityDetails(object):
    """
    The details for creating a certificate authority (CA).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCertificateAuthorityDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateCertificateAuthorityDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateCertificateAuthorityDetails.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateCertificateAuthorityDetails.
        :type compartment_id: str

        :param certificate_authority_rules:
            The value to assign to the certificate_authority_rules property of this CreateCertificateAuthorityDetails.
        :type certificate_authority_rules: list[oci.certificates_management.models.CertificateAuthorityRule]

        :param certificate_authority_config:
            The value to assign to the certificate_authority_config property of this CreateCertificateAuthorityDetails.
        :type certificate_authority_config: oci.certificates_management.models.CreateCertificateAuthorityConfigDetails

        :param certificate_revocation_list_details:
            The value to assign to the certificate_revocation_list_details property of this CreateCertificateAuthorityDetails.
        :type certificate_revocation_list_details: oci.certificates_management.models.CertificateRevocationListDetails

        :param kms_key_id:
            The value to assign to the kms_key_id property of this CreateCertificateAuthorityDetails.
        :type kms_key_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateCertificateAuthorityDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateCertificateAuthorityDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'certificate_authority_rules': 'list[CertificateAuthorityRule]',
            'certificate_authority_config': 'CreateCertificateAuthorityConfigDetails',
            'certificate_revocation_list_details': 'CertificateRevocationListDetails',
            'kms_key_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'certificate_authority_rules': 'certificateAuthorityRules',
            'certificate_authority_config': 'certificateAuthorityConfig',
            'certificate_revocation_list_details': 'certificateRevocationListDetails',
            'kms_key_id': 'kmsKeyId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._name = None
        self._description = None
        self._compartment_id = None
        self._certificate_authority_rules = None
        self._certificate_authority_config = None
        self._certificate_revocation_list_details = None
        self._kms_key_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateCertificateAuthorityDetails.
        A user-friendly name for the CA. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        :return: The name of this CreateCertificateAuthorityDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateCertificateAuthorityDetails.
        A user-friendly name for the CA. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        :param name: The name of this CreateCertificateAuthorityDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreateCertificateAuthorityDetails.
        A brief description of the CA.


        :return: The description of this CreateCertificateAuthorityDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateCertificateAuthorityDetails.
        A brief description of the CA.


        :param description: The description of this CreateCertificateAuthorityDetails.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateCertificateAuthorityDetails.
        The compartment in which you want to create the CA.


        :return: The compartment_id of this CreateCertificateAuthorityDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateCertificateAuthorityDetails.
        The compartment in which you want to create the CA.


        :param compartment_id: The compartment_id of this CreateCertificateAuthorityDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def certificate_authority_rules(self):
        """
        Gets the certificate_authority_rules of this CreateCertificateAuthorityDetails.
        A list of rules that control how the CA is used and managed.


        :return: The certificate_authority_rules of this CreateCertificateAuthorityDetails.
        :rtype: list[oci.certificates_management.models.CertificateAuthorityRule]
        """
        return self._certificate_authority_rules

    @certificate_authority_rules.setter
    def certificate_authority_rules(self, certificate_authority_rules):
        """
        Sets the certificate_authority_rules of this CreateCertificateAuthorityDetails.
        A list of rules that control how the CA is used and managed.


        :param certificate_authority_rules: The certificate_authority_rules of this CreateCertificateAuthorityDetails.
        :type: list[oci.certificates_management.models.CertificateAuthorityRule]
        """
        self._certificate_authority_rules = certificate_authority_rules

    @property
    def certificate_authority_config(self):
        """
        **[Required]** Gets the certificate_authority_config of this CreateCertificateAuthorityDetails.

        :return: The certificate_authority_config of this CreateCertificateAuthorityDetails.
        :rtype: oci.certificates_management.models.CreateCertificateAuthorityConfigDetails
        """
        return self._certificate_authority_config

    @certificate_authority_config.setter
    def certificate_authority_config(self, certificate_authority_config):
        """
        Sets the certificate_authority_config of this CreateCertificateAuthorityDetails.

        :param certificate_authority_config: The certificate_authority_config of this CreateCertificateAuthorityDetails.
        :type: oci.certificates_management.models.CreateCertificateAuthorityConfigDetails
        """
        self._certificate_authority_config = certificate_authority_config

    @property
    def certificate_revocation_list_details(self):
        """
        Gets the certificate_revocation_list_details of this CreateCertificateAuthorityDetails.

        :return: The certificate_revocation_list_details of this CreateCertificateAuthorityDetails.
        :rtype: oci.certificates_management.models.CertificateRevocationListDetails
        """
        return self._certificate_revocation_list_details

    @certificate_revocation_list_details.setter
    def certificate_revocation_list_details(self, certificate_revocation_list_details):
        """
        Sets the certificate_revocation_list_details of this CreateCertificateAuthorityDetails.

        :param certificate_revocation_list_details: The certificate_revocation_list_details of this CreateCertificateAuthorityDetails.
        :type: oci.certificates_management.models.CertificateRevocationListDetails
        """
        self._certificate_revocation_list_details = certificate_revocation_list_details

    @property
    def kms_key_id(self):
        """
        **[Required]** Gets the kms_key_id of this CreateCertificateAuthorityDetails.
        The OCID of the Oracle Cloud Infrastructure Vault key used to encrypt the CA.


        :return: The kms_key_id of this CreateCertificateAuthorityDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this CreateCertificateAuthorityDetails.
        The OCID of the Oracle Cloud Infrastructure Vault key used to encrypt the CA.


        :param kms_key_id: The kms_key_id of this CreateCertificateAuthorityDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateCertificateAuthorityDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateCertificateAuthorityDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateCertificateAuthorityDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateCertificateAuthorityDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateCertificateAuthorityDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateCertificateAuthorityDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateCertificateAuthorityDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateCertificateAuthorityDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .get_path_analysis_details import GetPathAnalysisDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AdhocGetPathAnalysisDetails(GetPathAnalysisDetails):
    """
    Defines the configuration for getting an ad-hoc path analysis.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AdhocGetPathAnalysisDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.vn_monitoring.models.AdhocGetPathAnalysisDetails.type` attribute
        of this class is ``ADHOC_QUERY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AdhocGetPathAnalysisDetails.
            Allowed values for this property are: "PERSISTED_QUERY", "ADHOC_QUERY"
        :type type: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AdhocGetPathAnalysisDetails.
        :type compartment_id: str

        :param protocol:
            The value to assign to the protocol property of this AdhocGetPathAnalysisDetails.
        :type protocol: int

        :param source_endpoint:
            The value to assign to the source_endpoint property of this AdhocGetPathAnalysisDetails.
        :type source_endpoint: oci.vn_monitoring.models.Endpoint

        :param destination_endpoint:
            The value to assign to the destination_endpoint property of this AdhocGetPathAnalysisDetails.
        :type destination_endpoint: oci.vn_monitoring.models.Endpoint

        :param protocol_parameters:
            The value to assign to the protocol_parameters property of this AdhocGetPathAnalysisDetails.
        :type protocol_parameters: oci.vn_monitoring.models.ProtocolParameters

        :param query_options:
            The value to assign to the query_options property of this AdhocGetPathAnalysisDetails.
        :type query_options: oci.vn_monitoring.models.QueryOptions

        """
        self.swagger_types = {
            'type': 'str',
            'compartment_id': 'str',
            'protocol': 'int',
            'source_endpoint': 'Endpoint',
            'destination_endpoint': 'Endpoint',
            'protocol_parameters': 'ProtocolParameters',
            'query_options': 'QueryOptions'
        }

        self.attribute_map = {
            'type': 'type',
            'compartment_id': 'compartmentId',
            'protocol': 'protocol',
            'source_endpoint': 'sourceEndpoint',
            'destination_endpoint': 'destinationEndpoint',
            'protocol_parameters': 'protocolParameters',
            'query_options': 'queryOptions'
        }

        self._type = None
        self._compartment_id = None
        self._protocol = None
        self._source_endpoint = None
        self._destination_endpoint = None
        self._protocol_parameters = None
        self._query_options = None
        self._type = 'ADHOC_QUERY'

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AdhocGetPathAnalysisDetails.
        The `OCID`__ for the compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this AdhocGetPathAnalysisDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AdhocGetPathAnalysisDetails.
        The `OCID`__ for the compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this AdhocGetPathAnalysisDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this AdhocGetPathAnalysisDetails.
        The IP protocol to used for the path analysis.


        :return: The protocol of this AdhocGetPathAnalysisDetails.
        :rtype: int
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this AdhocGetPathAnalysisDetails.
        The IP protocol to used for the path analysis.


        :param protocol: The protocol of this AdhocGetPathAnalysisDetails.
        :type: int
        """
        self._protocol = protocol

    @property
    def source_endpoint(self):
        """
        **[Required]** Gets the source_endpoint of this AdhocGetPathAnalysisDetails.

        :return: The source_endpoint of this AdhocGetPathAnalysisDetails.
        :rtype: oci.vn_monitoring.models.Endpoint
        """
        return self._source_endpoint

    @source_endpoint.setter
    def source_endpoint(self, source_endpoint):
        """
        Sets the source_endpoint of this AdhocGetPathAnalysisDetails.

        :param source_endpoint: The source_endpoint of this AdhocGetPathAnalysisDetails.
        :type: oci.vn_monitoring.models.Endpoint
        """
        self._source_endpoint = source_endpoint

    @property
    def destination_endpoint(self):
        """
        **[Required]** Gets the destination_endpoint of this AdhocGetPathAnalysisDetails.

        :return: The destination_endpoint of this AdhocGetPathAnalysisDetails.
        :rtype: oci.vn_monitoring.models.Endpoint
        """
        return self._destination_endpoint

    @destination_endpoint.setter
    def destination_endpoint(self, destination_endpoint):
        """
        Sets the destination_endpoint of this AdhocGetPathAnalysisDetails.

        :param destination_endpoint: The destination_endpoint of this AdhocGetPathAnalysisDetails.
        :type: oci.vn_monitoring.models.Endpoint
        """
        self._destination_endpoint = destination_endpoint

    @property
    def protocol_parameters(self):
        """
        Gets the protocol_parameters of this AdhocGetPathAnalysisDetails.

        :return: The protocol_parameters of this AdhocGetPathAnalysisDetails.
        :rtype: oci.vn_monitoring.models.ProtocolParameters
        """
        return self._protocol_parameters

    @protocol_parameters.setter
    def protocol_parameters(self, protocol_parameters):
        """
        Sets the protocol_parameters of this AdhocGetPathAnalysisDetails.

        :param protocol_parameters: The protocol_parameters of this AdhocGetPathAnalysisDetails.
        :type: oci.vn_monitoring.models.ProtocolParameters
        """
        self._protocol_parameters = protocol_parameters

    @property
    def query_options(self):
        """
        Gets the query_options of this AdhocGetPathAnalysisDetails.

        :return: The query_options of this AdhocGetPathAnalysisDetails.
        :rtype: oci.vn_monitoring.models.QueryOptions
        """
        return self._query_options

    @query_options.setter
    def query_options(self, query_options):
        """
        Sets the query_options of this AdhocGetPathAnalysisDetails.

        :param query_options: The query_options of this AdhocGetPathAnalysisDetails.
        :type: oci.vn_monitoring.models.QueryOptions
        """
        self._query_options = query_options

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResponseCachingPolicy(object):
    """
    An object that specifies an HTTP response caching policy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResponseCachingPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_response_header_based_caching_enabled:
            The value to assign to the is_response_header_based_caching_enabled property of this ResponseCachingPolicy.
        :type is_response_header_based_caching_enabled: bool

        """
        self.swagger_types = {
            'is_response_header_based_caching_enabled': 'bool'
        }

        self.attribute_map = {
            'is_response_header_based_caching_enabled': 'isResponseHeaderBasedCachingEnabled'
        }

        self._is_response_header_based_caching_enabled = None

    @property
    def is_response_header_based_caching_enabled(self):
        """
        Gets the is_response_header_based_caching_enabled of this ResponseCachingPolicy.
        When false, responses will not be cached by the backend based on response headers.

        When true, responses that contain one of the supported cache control headers will be cached according to the
        values specified in the cache control headers.

        The \"X-Accel-Expires\" header field sets caching time of a response in seconds. The zero value disables
        caching for a response. If the value starts with the @ prefix, it sets an absolute time in seconds since
        Epoch, up to which the response may be cached.

        If the header does not include the \"X-Accel-Expires\" field, parameters of caching may be set in the header
        fields \"Expires\" or \"Cache-Control\".

        If the header includes the \"Set-Cookie\" field, such a response will not be cached.

        If the header includes the \"Vary\" field with the special value \"*\", such a response will not be cached. If the
        header includes the \"Vary\" field with another value, such a response will be cached taking into account the
        corresponding request header fields.


        :return: The is_response_header_based_caching_enabled of this ResponseCachingPolicy.
        :rtype: bool
        """
        return self._is_response_header_based_caching_enabled

    @is_response_header_based_caching_enabled.setter
    def is_response_header_based_caching_enabled(self, is_response_header_based_caching_enabled):
        """
        Sets the is_response_header_based_caching_enabled of this ResponseCachingPolicy.
        When false, responses will not be cached by the backend based on response headers.

        When true, responses that contain one of the supported cache control headers will be cached according to the
        values specified in the cache control headers.

        The \"X-Accel-Expires\" header field sets caching time of a response in seconds. The zero value disables
        caching for a response. If the value starts with the @ prefix, it sets an absolute time in seconds since
        Epoch, up to which the response may be cached.

        If the header does not include the \"X-Accel-Expires\" field, parameters of caching may be set in the header
        fields \"Expires\" or \"Cache-Control\".

        If the header includes the \"Set-Cookie\" field, such a response will not be cached.

        If the header includes the \"Vary\" field with the special value \"*\", such a response will not be cached. If the
        header includes the \"Vary\" field with another value, such a response will be cached taking into account the
        corresponding request header fields.


        :param is_response_header_based_caching_enabled: The is_response_header_based_caching_enabled of this ResponseCachingPolicy.
        :type: bool
        """
        self._is_response_header_based_caching_enabled = is_response_header_based_caching_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .opsi_data_object_summary import OpsiDataObjectSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseInsightsDataObjectSummary(OpsiDataObjectSummary):
    """
    Summary of a database insights data object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseInsightsDataObjectSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.DatabaseInsightsDataObjectSummary.data_object_type` attribute
        of this class is ``DATABASE_INSIGHTS_DATA_OBJECT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param identifier:
            The value to assign to the identifier property of this DatabaseInsightsDataObjectSummary.
        :type identifier: str

        :param data_object_type:
            The value to assign to the data_object_type property of this DatabaseInsightsDataObjectSummary.
            Allowed values for this property are: "DATABASE_INSIGHTS_DATA_OBJECT", "HOST_INSIGHTS_DATA_OBJECT", "EXADATA_INSIGHTS_DATA_OBJECT"
        :type data_object_type: str

        :param display_name:
            The value to assign to the display_name property of this DatabaseInsightsDataObjectSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this DatabaseInsightsDataObjectSummary.
        :type description: str

        """
        self.swagger_types = {
            'identifier': 'str',
            'data_object_type': 'str',
            'display_name': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'identifier': 'identifier',
            'data_object_type': 'dataObjectType',
            'display_name': 'displayName',
            'description': 'description'
        }

        self._identifier = None
        self._data_object_type = None
        self._display_name = None
        self._description = None
        self._data_object_type = 'DATABASE_INSIGHTS_DATA_OBJECT'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Repository(object):
    """
    Repositories containing the source code to build and deploy.
    """

    #: A constant which can be used with the repository_type property of a Repository.
    #: This constant has a value of "MIRRORED"
    REPOSITORY_TYPE_MIRRORED = "MIRRORED"

    #: A constant which can be used with the repository_type property of a Repository.
    #: This constant has a value of "HOSTED"
    REPOSITORY_TYPE_HOSTED = "HOSTED"

    #: A constant which can be used with the lifecycle_state property of a Repository.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Repository.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Repository.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the trigger_build_events property of a Repository.
    #: This constant has a value of "PUSH"
    TRIGGER_BUILD_EVENTS_PUSH = "PUSH"

    #: A constant which can be used with the trigger_build_events property of a Repository.
    #: This constant has a value of "COMMIT_UPDATES"
    TRIGGER_BUILD_EVENTS_COMMIT_UPDATES = "COMMIT_UPDATES"

    def __init__(self, **kwargs):
        """
        Initializes a new Repository object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Repository.
        :type id: str

        :param name:
            The value to assign to the name property of this Repository.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Repository.
        :type compartment_id: str

        :param namespace:
            The value to assign to the namespace property of this Repository.
        :type namespace: str

        :param project_id:
            The value to assign to the project_id property of this Repository.
        :type project_id: str

        :param project_name:
            The value to assign to the project_name property of this Repository.
        :type project_name: str

        :param ssh_url:
            The value to assign to the ssh_url property of this Repository.
        :type ssh_url: str

        :param http_url:
            The value to assign to the http_url property of this Repository.
        :type http_url: str

        :param description:
            The value to assign to the description property of this Repository.
        :type description: str

        :param default_branch:
            The value to assign to the default_branch property of this Repository.
        :type default_branch: str

        :param repository_type:
            The value to assign to the repository_type property of this Repository.
            Allowed values for this property are: "MIRRORED", "HOSTED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type repository_type: str

        :param mirror_repository_config:
            The value to assign to the mirror_repository_config property of this Repository.
        :type mirror_repository_config: oci.devops.models.MirrorRepositoryConfig

        :param time_created:
            The value to assign to the time_created property of this Repository.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Repository.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Repository.
            Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecyle_details:
            The value to assign to the lifecyle_details property of this Repository.
        :type lifecyle_details: str

        :param branch_count:
            The value to assign to the branch_count property of this Repository.
        :type branch_count: int

        :param commit_count:
            The value to assign to the commit_count property of this Repository.
        :type commit_count: int

        :param size_in_bytes:
            The value to assign to the size_in_bytes property of this Repository.
        :type size_in_bytes: int

        :param trigger_build_events:
            The value to assign to the trigger_build_events property of this Repository.
            Allowed values for items in this list are: "PUSH", "COMMIT_UPDATES", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type trigger_build_events: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Repository.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Repository.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this Repository.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'compartment_id': 'str',
            'namespace': 'str',
            'project_id': 'str',
            'project_name': 'str',
            'ssh_url': 'str',
            'http_url': 'str',
            'description': 'str',
            'default_branch': 'str',
            'repository_type': 'str',
            'mirror_repository_config': 'MirrorRepositoryConfig',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecyle_details': 'str',
            'branch_count': 'int',
            'commit_count': 'int',
            'size_in_bytes': 'int',
            'trigger_build_events': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'compartment_id': 'compartmentId',
            'namespace': 'namespace',
            'project_id': 'projectId',
            'project_name': 'projectName',
            'ssh_url': 'sshUrl',
            'http_url': 'httpUrl',
            'description': 'description',
            'default_branch': 'defaultBranch',
            'repository_type': 'repositoryType',
            'mirror_repository_config': 'mirrorRepositoryConfig',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecyle_details': 'lifecyleDetails',
            'branch_count': 'branchCount',
            'commit_count': 'commitCount',
            'size_in_bytes': 'sizeInBytes',
            'trigger_build_events': 'triggerBuildEvents',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._name = None
        self._compartment_id = None
        self._namespace = None
        self._project_id = None
        self._project_name = None
        self._ssh_url = None
        self._http_url = None
        self._description = None
        self._default_branch = None
        self._repository_type = None
        self._mirror_repository_config = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecyle_details = None
        self._branch_count = None
        self._commit_count = None
        self._size_in_bytes = None
        self._trigger_build_events = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Repository.
        The OCID of the repository. This value is unique and immutable.


        :return: The id of this Repository.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Repository.
        The OCID of the repository. This value is unique and immutable.


        :param id: The id of this Repository.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Repository.
        Unique name of a repository. This value is mutable.


        :return: The name of this Repository.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Repository.
        Unique name of a repository. This value is mutable.


        :param name: The name of this Repository.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Repository.
        The OCID of the repository's compartment.


        :return: The compartment_id of this Repository.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Repository.
        The OCID of the repository's compartment.


        :param compartment_id: The compartment_id of this Repository.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def namespace(self):
        """
        Gets the namespace of this Repository.
        Tenancy unique namespace.


        :return: The namespace of this Repository.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this Repository.
        Tenancy unique namespace.


        :param namespace: The namespace of this Repository.
        :type: str
        """
        self._namespace = namespace

    @property
    def project_id(self):
        """
        **[Required]** Gets the project_id of this Repository.
        The OCID of the DevOps project containing the repository.


        :return: The project_id of this Repository.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """
        Sets the project_id of this Repository.
        The OCID of the DevOps project containing the repository.


        :param project_id: The project_id of this Repository.
        :type: str
        """
        self._project_id = project_id

    @property
    def project_name(self):
        """
        Gets the project_name of this Repository.
        Unique project name in a namespace.


        :return: The project_name of this Repository.
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """
        Sets the project_name of this Repository.
        Unique project name in a namespace.


        :param project_name: The project_name of this Repository.
        :type: str
        """
        self._project_name = project_name

    @property
    def ssh_url(self):
        """
        Gets the ssh_url of this Repository.
        SSH URL that you use to git clone, pull and push.


        :return: The ssh_url of this Repository.
        :rtype: str
        """
        return self._ssh_url

    @ssh_url.setter
    def ssh_url(self, ssh_url):
        """
        Sets the ssh_url of this Repository.
        SSH URL that you use to git clone, pull and push.


        :param ssh_url: The ssh_url of this Repository.
        :type: str
        """
        self._ssh_url = ssh_url

    @property
    def http_url(self):
        """
        Gets the http_url of this Repository.
        HTTP URL that you use to git clone, pull and push.


        :return: The http_url of this Repository.
        :rtype: str
        """
        return self._http_url

    @http_url.setter
    def http_url(self, http_url):
        """
        Sets the http_url of this Repository.
        HTTP URL that you use to git clone, pull and push.


        :param http_url: The http_url of this Repository.
        :type: str
        """
        self._http_url = http_url

    @property
    def description(self):
        """
        Gets the description of this Repository.
        Details of the repository. Avoid entering confidential information.


        :return: The description of this Repository.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Repository.
        Details of the repository. Avoid entering confidential information.


        :param description: The description of this Repository.
        :type: str
        """
        self._description = description

    @property
    def default_branch(self):
        """
        Gets the default_branch of this Repository.
        The default branch of the repository.


        :return: The default_branch of this Repository.
        :rtype: str
        """
        return self._default_branch

    @default_branch.setter
    def default_branch(self, default_branch):
        """
        Sets the default_branch of this Repository.
        The default branch of the repository.


        :param default_branch: The default_branch of this Repository.
        :type: str
        """
        self._default_branch = default_branch

    @property
    def repository_type(self):
        """
        Gets the repository_type of this Repository.
        Type of repository:
        MIRRORED - Repository created by mirroring an existing repository.
        HOSTED - Repository created and hosted using OCI DevOps code repository.

        Allowed values for this property are: "MIRRORED", "HOSTED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The repository_type of this Repository.
        :rtype: str
        """
        return self._repository_type

    @repository_type.setter
    def repository_type(self, repository_type):
        """
        Sets the repository_type of this Repository.
        Type of repository:
        MIRRORED - Repository created by mirroring an existing repository.
        HOSTED - Repository created and hosted using OCI DevOps code repository.


        :param repository_type: The repository_type of this Repository.
        :type: str
        """
        allowed_values = ["MIRRORED", "HOSTED"]
        if not value_allowed_none_or_none_sentinel(repository_type, allowed_values):
            repository_type = 'UNKNOWN_ENUM_VALUE'
        self._repository_type = repository_type

    @property
    def mirror_repository_config(self):
        """
        Gets the mirror_repository_config of this Repository.

        :return: The mirror_repository_config of this Repository.
        :rtype: oci.devops.models.MirrorRepositoryConfig
        """
        return self._mirror_repository_config

    @mirror_repository_config.setter
    def mirror_repository_config(self, mirror_repository_config):
        """
        Sets the mirror_repository_config of this Repository.

        :param mirror_repository_config: The mirror_repository_config of this Repository.
        :type: oci.devops.models.MirrorRepositoryConfig
        """
        self._mirror_repository_config = mirror_repository_config

    @property
    def time_created(self):
        """
        Gets the time_created of this Repository.
        The time the repository was created. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :return: The time_created of this Repository.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Repository.
        The time the repository was created. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :param time_created: The time_created of this Repository.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Repository.
        The time the repository was updated. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :return: The time_updated of this Repository.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Repository.
        The time the repository was updated. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :param time_updated: The time_updated of this Repository.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Repository.
        The current state of the repository.

        Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Repository.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Repository.
        The current state of the repository.


        :param lifecycle_state: The lifecycle_state of this Repository.
        :type: str
        """
        allowed_values = ["ACTIVE", "CREATING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecyle_details(self):
        """
        Gets the lifecyle_details of this Repository.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecyle_details of this Repository.
        :rtype: str
        """
        return self._lifecyle_details

    @lifecyle_details.setter
    def lifecyle_details(self, lifecyle_details):
        """
        Sets the lifecyle_details of this Repository.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecyle_details: The lifecyle_details of this Repository.
        :type: str
        """
        self._lifecyle_details = lifecyle_details

    @property
    def branch_count(self):
        """
        Gets the branch_count of this Repository.
        The count of the branches present in the repository.


        :return: The branch_count of this Repository.
        :rtype: int
        """
        return self._branch_count

    @branch_count.setter
    def branch_count(self, branch_count):
        """
        Sets the branch_count of this Repository.
        The count of the branches present in the repository.


        :param branch_count: The branch_count of this Repository.
        :type: int
        """
        self._branch_count = branch_count

    @property
    def commit_count(self):
        """
        Gets the commit_count of this Repository.
        The count of the commits present in the repository.


        :return: The commit_count of this Repository.
        :rtype: int
        """
        return self._commit_count

    @commit_count.setter
    def commit_count(self, commit_count):
        """
        Sets the commit_count of this Repository.
        The count of the commits present in the repository.


        :param commit_count: The commit_count of this Repository.
        :type: int
        """
        self._commit_count = commit_count

    @property
    def size_in_bytes(self):
        """
        Gets the size_in_bytes of this Repository.
        The size of the repository in bytes.


        :return: The size_in_bytes of this Repository.
        :rtype: int
        """
        return self._size_in_bytes

    @size_in_bytes.setter
    def size_in_bytes(self, size_in_bytes):
        """
        Sets the size_in_bytes of this Repository.
        The size of the repository in bytes.


        :param size_in_bytes: The size_in_bytes of this Repository.
        :type: int
        """
        self._size_in_bytes = size_in_bytes

    @property
    def trigger_build_events(self):
        """
        Gets the trigger_build_events of this Repository.
        Trigger build events supported for this repository:
        PUSH - Build is triggered when a push event occurs.
        COMMIT_UPDATES - Build is triggered when new commits are mirrored into a repository.

        Allowed values for items in this list are: "PUSH", "COMMIT_UPDATES", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The trigger_build_events of this Repository.
        :rtype: list[str]
        """
        return self._trigger_build_events

    @trigger_build_events.setter
    def trigger_build_events(self, trigger_build_events):
        """
        Sets the trigger_build_events of this Repository.
        Trigger build events supported for this repository:
        PUSH - Build is triggered when a push event occurs.
        COMMIT_UPDATES - Build is triggered when new commits are mirrored into a repository.


        :param trigger_build_events: The trigger_build_events of this Repository.
        :type: list[str]
        """
        allowed_values = ["PUSH", "COMMIT_UPDATES"]
        if trigger_build_events:
            trigger_build_events[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in trigger_build_events]
        self._trigger_build_events = trigger_build_events

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Repository.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Repository.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Repository.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Repository.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Repository.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Repository.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Repository.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Repository.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Repository.
        Usage of system tag keys. These predefined keys are scoped to namespaces. See `Resource Tags`__. Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this Repository.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Repository.
        Usage of system tag keys. These predefined keys are scoped to namespaces. See `Resource Tags`__. Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this Repository.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_channel_details import UpdateChannelDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateTwilioChannelDetails(UpdateChannelDetails):
    """
    Properties to update a Twilio channel.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateTwilioChannelDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.UpdateTwilioChannelDetails.type` attribute
        of this class is ``TWILIO`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateTwilioChannelDetails.
        :type description: str

        :param type:
            The value to assign to the type property of this UpdateTwilioChannelDetails.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK"
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this UpdateTwilioChannelDetails.
        :type session_expiry_duration_in_milliseconds: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateTwilioChannelDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateTwilioChannelDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param account_sid:
            The value to assign to the account_sid property of this UpdateTwilioChannelDetails.
        :type account_sid: str

        :param phone_number:
            The value to assign to the phone_number property of this UpdateTwilioChannelDetails.
        :type phone_number: str

        :param auth_token:
            The value to assign to the auth_token property of this UpdateTwilioChannelDetails.
        :type auth_token: str

        :param is_mms_enabled:
            The value to assign to the is_mms_enabled property of this UpdateTwilioChannelDetails.
        :type is_mms_enabled: bool

        :param original_connectors_url:
            The value to assign to the original_connectors_url property of this UpdateTwilioChannelDetails.
        :type original_connectors_url: str

        :param bot_id:
            The value to assign to the bot_id property of this UpdateTwilioChannelDetails.
        :type bot_id: str

        """
        self.swagger_types = {
            'description': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'account_sid': 'str',
            'phone_number': 'str',
            'auth_token': 'str',
            'is_mms_enabled': 'bool',
            'original_connectors_url': 'str',
            'bot_id': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'account_sid': 'accountSID',
            'phone_number': 'phoneNumber',
            'auth_token': 'authToken',
            'is_mms_enabled': 'isMmsEnabled',
            'original_connectors_url': 'originalConnectorsUrl',
            'bot_id': 'botId'
        }

        self._description = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._freeform_tags = None
        self._defined_tags = None
        self._account_sid = None
        self._phone_number = None
        self._auth_token = None
        self._is_mms_enabled = None
        self._original_connectors_url = None
        self._bot_id = None
        self._type = 'TWILIO'

    @property
    def account_sid(self):
        """
        Gets the account_sid of this UpdateTwilioChannelDetails.
        The Account SID for the Twilio number.


        :return: The account_sid of this UpdateTwilioChannelDetails.
        :rtype: str
        """
        return self._account_sid

    @account_sid.setter
    def account_sid(self, account_sid):
        """
        Sets the account_sid of this UpdateTwilioChannelDetails.
        The Account SID for the Twilio number.


        :param account_sid: The account_sid of this UpdateTwilioChannelDetails.
        :type: str
        """
        self._account_sid = account_sid

    @property
    def phone_number(self):
        """
        Gets the phone_number of this UpdateTwilioChannelDetails.
        The Twilio phone number.


        :return: The phone_number of this UpdateTwilioChannelDetails.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this UpdateTwilioChannelDetails.
        The Twilio phone number.


        :param phone_number: The phone_number of this UpdateTwilioChannelDetails.
        :type: str
        """
        self._phone_number = phone_number

    @property
    def auth_token(self):
        """
        Gets the auth_token of this UpdateTwilioChannelDetails.
        The Auth Token for the Twilio number.


        :return: The auth_token of this UpdateTwilioChannelDetails.
        :rtype: str
        """
        return self._auth_token

    @auth_token.setter
    def auth_token(self, auth_token):
        """
        Sets the auth_token of this UpdateTwilioChannelDetails.
        The Auth Token for the Twilio number.


        :param auth_token: The auth_token of this UpdateTwilioChannelDetails.
        :type: str
        """
        self._auth_token = auth_token

    @property
    def is_mms_enabled(self):
        """
        Gets the is_mms_enabled of this UpdateTwilioChannelDetails.
        Whether MMS is enabled for this channel or not.


        :return: The is_mms_enabled of this UpdateTwilioChannelDetails.
        :rtype: bool
        """
        return self._is_mms_enabled

    @is_mms_enabled.setter
    def is_mms_enabled(self, is_mms_enabled):
        """
        Sets the is_mms_enabled of this UpdateTwilioChannelDetails.
        Whether MMS is enabled for this channel or not.


        :param is_mms_enabled: The is_mms_enabled of this UpdateTwilioChannelDetails.
        :type: bool
        """
        self._is_mms_enabled = is_mms_enabled

    @property
    def original_connectors_url(self):
        """
        Gets the original_connectors_url of this UpdateTwilioChannelDetails.
        The original connectors URL (used for backward compatibility).


        :return: The original_connectors_url of this UpdateTwilioChannelDetails.
        :rtype: str
        """
        return self._original_connectors_url

    @original_connectors_url.setter
    def original_connectors_url(self, original_connectors_url):
        """
        Sets the original_connectors_url of this UpdateTwilioChannelDetails.
        The original connectors URL (used for backward compatibility).


        :param original_connectors_url: The original_connectors_url of this UpdateTwilioChannelDetails.
        :type: str
        """
        self._original_connectors_url = original_connectors_url

    @property
    def bot_id(self):
        """
        Gets the bot_id of this UpdateTwilioChannelDetails.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :return: The bot_id of this UpdateTwilioChannelDetails.
        :rtype: str
        """
        return self._bot_id

    @bot_id.setter
    def bot_id(self, bot_id):
        """
        Sets the bot_id of this UpdateTwilioChannelDetails.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :param bot_id: The bot_id of this UpdateTwilioChannelDetails.
        :type: str
        """
        self._bot_id = bot_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitoredResourceAssociation(object):
    """
    Association between two monitored resources.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitoredResourceAssociation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param association_type:
            The value to assign to the association_type property of this MonitoredResourceAssociation.
        :type association_type: str

        :param compartment_id:
            The value to assign to the compartment_id property of this MonitoredResourceAssociation.
        :type compartment_id: str

        :param tenant_id:
            The value to assign to the tenant_id property of this MonitoredResourceAssociation.
        :type tenant_id: str

        :param source_resource_id:
            The value to assign to the source_resource_id property of this MonitoredResourceAssociation.
        :type source_resource_id: str

        :param destination_resource_id:
            The value to assign to the destination_resource_id property of this MonitoredResourceAssociation.
        :type destination_resource_id: str

        :param source_resource_details:
            The value to assign to the source_resource_details property of this MonitoredResourceAssociation.
        :type source_resource_details: oci.stack_monitoring.models.AssociationResourceDetails

        :param destination_resource_details:
            The value to assign to the destination_resource_details property of this MonitoredResourceAssociation.
        :type destination_resource_details: oci.stack_monitoring.models.AssociationResourceDetails

        :param time_created:
            The value to assign to the time_created property of this MonitoredResourceAssociation.
        :type time_created: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this MonitoredResourceAssociation.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this MonitoredResourceAssociation.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this MonitoredResourceAssociation.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'association_type': 'str',
            'compartment_id': 'str',
            'tenant_id': 'str',
            'source_resource_id': 'str',
            'destination_resource_id': 'str',
            'source_resource_details': 'AssociationResourceDetails',
            'destination_resource_details': 'AssociationResourceDetails',
            'time_created': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'association_type': 'associationType',
            'compartment_id': 'compartmentId',
            'tenant_id': 'tenantId',
            'source_resource_id': 'sourceResourceId',
            'destination_resource_id': 'destinationResourceId',
            'source_resource_details': 'sourceResourceDetails',
            'destination_resource_details': 'destinationResourceDetails',
            'time_created': 'timeCreated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._association_type = None
        self._compartment_id = None
        self._tenant_id = None
        self._source_resource_id = None
        self._destination_resource_id = None
        self._source_resource_details = None
        self._destination_resource_details = None
        self._time_created = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def association_type(self):
        """
        **[Required]** Gets the association_type of this MonitoredResourceAssociation.
        Association Type


        :return: The association_type of this MonitoredResourceAssociation.
        :rtype: str
        """
        return self._association_type

    @association_type.setter
    def association_type(self, association_type):
        """
        Sets the association_type of this MonitoredResourceAssociation.
        Association Type


        :param association_type: The association_type of this MonitoredResourceAssociation.
        :type: str
        """
        self._association_type = association_type

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this MonitoredResourceAssociation.
        Compartment Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this MonitoredResourceAssociation.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this MonitoredResourceAssociation.
        Compartment Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this MonitoredResourceAssociation.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def tenant_id(self):
        """
        **[Required]** Gets the tenant_id of this MonitoredResourceAssociation.
        Tenancy Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The tenant_id of this MonitoredResourceAssociation.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this MonitoredResourceAssociation.
        Tenancy Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param tenant_id: The tenant_id of this MonitoredResourceAssociation.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def source_resource_id(self):
        """
        **[Required]** Gets the source_resource_id of this MonitoredResourceAssociation.
        Source Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The source_resource_id of this MonitoredResourceAssociation.
        :rtype: str
        """
        return self._source_resource_id

    @source_resource_id.setter
    def source_resource_id(self, source_resource_id):
        """
        Sets the source_resource_id of this MonitoredResourceAssociation.
        Source Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param source_resource_id: The source_resource_id of this MonitoredResourceAssociation.
        :type: str
        """
        self._source_resource_id = source_resource_id

    @property
    def destination_resource_id(self):
        """
        **[Required]** Gets the destination_resource_id of this MonitoredResourceAssociation.
        Destination Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The destination_resource_id of this MonitoredResourceAssociation.
        :rtype: str
        """
        return self._destination_resource_id

    @destination_resource_id.setter
    def destination_resource_id(self, destination_resource_id):
        """
        Sets the destination_resource_id of this MonitoredResourceAssociation.
        Destination Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param destination_resource_id: The destination_resource_id of this MonitoredResourceAssociation.
        :type: str
        """
        self._destination_resource_id = destination_resource_id

    @property
    def source_resource_details(self):
        """
        Gets the source_resource_details of this MonitoredResourceAssociation.

        :return: The source_resource_details of this MonitoredResourceAssociation.
        :rtype: oci.stack_monitoring.models.AssociationResourceDetails
        """
        return self._source_resource_details

    @source_resource_details.setter
    def source_resource_details(self, source_resource_details):
        """
        Sets the source_resource_details of this MonitoredResourceAssociation.

        :param source_resource_details: The source_resource_details of this MonitoredResourceAssociation.
        :type: oci.stack_monitoring.models.AssociationResourceDetails
        """
        self._source_resource_details = source_resource_details

    @property
    def destination_resource_details(self):
        """
        Gets the destination_resource_details of this MonitoredResourceAssociation.

        :return: The destination_resource_details of this MonitoredResourceAssociation.
        :rtype: oci.stack_monitoring.models.AssociationResourceDetails
        """
        return self._destination_resource_details

    @destination_resource_details.setter
    def destination_resource_details(self, destination_resource_details):
        """
        Sets the destination_resource_details of this MonitoredResourceAssociation.

        :param destination_resource_details: The destination_resource_details of this MonitoredResourceAssociation.
        :type: oci.stack_monitoring.models.AssociationResourceDetails
        """
        self._destination_resource_details = destination_resource_details

    @property
    def time_created(self):
        """
        Gets the time_created of this MonitoredResourceAssociation.
        The time when the association was created. An RFC3339 formatted datetime string


        :return: The time_created of this MonitoredResourceAssociation.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this MonitoredResourceAssociation.
        The time when the association was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this MonitoredResourceAssociation.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this MonitoredResourceAssociation.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this MonitoredResourceAssociation.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this MonitoredResourceAssociation.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this MonitoredResourceAssociation.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this MonitoredResourceAssociation.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this MonitoredResourceAssociation.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this MonitoredResourceAssociation.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this MonitoredResourceAssociation.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this MonitoredResourceAssociation.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this MonitoredResourceAssociation.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this MonitoredResourceAssociation.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this MonitoredResourceAssociation.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VirtualDeploymentListener(object):
    """
    Listener configuration for a virtual deployment.
    """

    #: A constant which can be used with the protocol property of a VirtualDeploymentListener.
    #: This constant has a value of "HTTP"
    PROTOCOL_HTTP = "HTTP"

    #: A constant which can be used with the protocol property of a VirtualDeploymentListener.
    #: This constant has a value of "TLS_PASSTHROUGH"
    PROTOCOL_TLS_PASSTHROUGH = "TLS_PASSTHROUGH"

    #: A constant which can be used with the protocol property of a VirtualDeploymentListener.
    #: This constant has a value of "TCP"
    PROTOCOL_TCP = "TCP"

    #: A constant which can be used with the protocol property of a VirtualDeploymentListener.
    #: This constant has a value of "HTTP2"
    PROTOCOL_HTTP2 = "HTTP2"

    #: A constant which can be used with the protocol property of a VirtualDeploymentListener.
    #: This constant has a value of "GRPC"
    PROTOCOL_GRPC = "GRPC"

    def __init__(self, **kwargs):
        """
        Initializes a new VirtualDeploymentListener object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param protocol:
            The value to assign to the protocol property of this VirtualDeploymentListener.
            Allowed values for this property are: "HTTP", "TLS_PASSTHROUGH", "TCP", "HTTP2", "GRPC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type protocol: str

        :param port:
            The value to assign to the port property of this VirtualDeploymentListener.
        :type port: int

        """
        self.swagger_types = {
            'protocol': 'str',
            'port': 'int'
        }

        self.attribute_map = {
            'protocol': 'protocol',
            'port': 'port'
        }

        self._protocol = None
        self._port = None

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this VirtualDeploymentListener.
        Type of protocol used in virtual deployment.

        Allowed values for this property are: "HTTP", "TLS_PASSTHROUGH", "TCP", "HTTP2", "GRPC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The protocol of this VirtualDeploymentListener.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this VirtualDeploymentListener.
        Type of protocol used in virtual deployment.


        :param protocol: The protocol of this VirtualDeploymentListener.
        :type: str
        """
        allowed_values = ["HTTP", "TLS_PASSTHROUGH", "TCP", "HTTP2", "GRPC"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            protocol = 'UNKNOWN_ENUM_VALUE'
        self._protocol = protocol

    @property
    def port(self):
        """
        **[Required]** Gets the port of this VirtualDeploymentListener.
        Port in which virtual deployment is running.


        :return: The port of this VirtualDeploymentListener.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this VirtualDeploymentListener.
        Port in which virtual deployment is running.


        :param port: The port of this VirtualDeploymentListener.
        :type: int
        """
        self._port = port

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .monitoring_source_namespace_details import MonitoringSourceNamespaceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitoringSourceSelectedNamespaceDetails(MonitoringSourceNamespaceDetails):
    """
    The namespaces for the compartment-specific list.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitoringSourceSelectedNamespaceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.sch.models.MonitoringSourceSelectedNamespaceDetails.kind` attribute
        of this class is ``selected`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this MonitoringSourceSelectedNamespaceDetails.
            Allowed values for this property are: "selected"
        :type kind: str

        :param namespaces:
            The value to assign to the namespaces property of this MonitoringSourceSelectedNamespaceDetails.
        :type namespaces: list[oci.sch.models.MonitoringSourceSelectedNamespace]

        """
        self.swagger_types = {
            'kind': 'str',
            'namespaces': 'list[MonitoringSourceSelectedNamespace]'
        }

        self.attribute_map = {
            'kind': 'kind',
            'namespaces': 'namespaces'
        }

        self._kind = None
        self._namespaces = None
        self._kind = 'selected'

    @property
    def namespaces(self):
        """
        **[Required]** Gets the namespaces of this MonitoringSourceSelectedNamespaceDetails.
        The namespaces for the compartment-specific list.


        :return: The namespaces of this MonitoringSourceSelectedNamespaceDetails.
        :rtype: list[oci.sch.models.MonitoringSourceSelectedNamespace]
        """
        return self._namespaces

    @namespaces.setter
    def namespaces(self, namespaces):
        """
        Sets the namespaces of this MonitoringSourceSelectedNamespaceDetails.
        The namespaces for the compartment-specific list.


        :param namespaces: The namespaces of this MonitoringSourceSelectedNamespaceDetails.
        :type: list[oci.sch.models.MonitoringSourceSelectedNamespace]
        """
        self._namespaces = namespaces

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateTranslatorDetails(object):
    """
    Properties that are required to create a Translator.
    """

    #: A constant which can be used with the type property of a CreateTranslatorDetails.
    #: This constant has a value of "GOOGLE"
    TYPE_GOOGLE = "GOOGLE"

    #: A constant which can be used with the type property of a CreateTranslatorDetails.
    #: This constant has a value of "MICROSOFT"
    TYPE_MICROSOFT = "MICROSOFT"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateTranslatorDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this CreateTranslatorDetails.
            Allowed values for this property are: "GOOGLE", "MICROSOFT"
        :type type: str

        :param base_url:
            The value to assign to the base_url property of this CreateTranslatorDetails.
        :type base_url: str

        :param auth_token:
            The value to assign to the auth_token property of this CreateTranslatorDetails.
        :type auth_token: str

        :param properties:
            The value to assign to the properties property of this CreateTranslatorDetails.
        :type properties: dict(str, str)

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateTranslatorDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateTranslatorDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'type': 'str',
            'base_url': 'str',
            'auth_token': 'str',
            'properties': 'dict(str, str)',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'type': 'type',
            'base_url': 'baseUrl',
            'auth_token': 'authToken',
            'properties': 'properties',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._type = None
        self._base_url = None
        self._auth_token = None
        self._properties = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def type(self):
        """
        **[Required]** Gets the type of this CreateTranslatorDetails.
        The Translation Service to use for this Translator.

        Allowed values for this property are: "GOOGLE", "MICROSOFT"


        :return: The type of this CreateTranslatorDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CreateTranslatorDetails.
        The Translation Service to use for this Translator.


        :param type: The type of this CreateTranslatorDetails.
        :type: str
        """
        allowed_values = ["GOOGLE", "MICROSOFT"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            raise ValueError(
                "Invalid value for `type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def base_url(self):
        """
        **[Required]** Gets the base_url of this CreateTranslatorDetails.
        The base URL for invoking the Translation Service.


        :return: The base_url of this CreateTranslatorDetails.
        :rtype: str
        """
        return self._base_url

    @base_url.setter
    def base_url(self, base_url):
        """
        Sets the base_url of this CreateTranslatorDetails.
        The base URL for invoking the Translation Service.


        :param base_url: The base_url of this CreateTranslatorDetails.
        :type: str
        """
        self._base_url = base_url

    @property
    def auth_token(self):
        """
        **[Required]** Gets the auth_token of this CreateTranslatorDetails.
        The authentication token to use when invoking the Translation Service


        :return: The auth_token of this CreateTranslatorDetails.
        :rtype: str
        """
        return self._auth_token

    @auth_token.setter
    def auth_token(self, auth_token):
        """
        Sets the auth_token of this CreateTranslatorDetails.
        The authentication token to use when invoking the Translation Service


        :param auth_token: The auth_token of this CreateTranslatorDetails.
        :type: str
        """
        self._auth_token = auth_token

    @property
    def properties(self):
        """
        Gets the properties of this CreateTranslatorDetails.
        Properties used when invoking the translation service.
        Each property is a simple key-value pair.


        :return: The properties of this CreateTranslatorDetails.
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this CreateTranslatorDetails.
        Properties used when invoking the translation service.
        Each property is a simple key-value pair.


        :param properties: The properties of this CreateTranslatorDetails.
        :type: dict(str, str)
        """
        self._properties = properties

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateTranslatorDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateTranslatorDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateTranslatorDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateTranslatorDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateTranslatorDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateTranslatorDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateTranslatorDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateTranslatorDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
